@@ -5,7 +5,7 @@ use utf8;
 use DBI;
 use Lemonldap::NG::Common::Conf::Constants;    #inherits
 
-our $VERSION = '1.9.13';
+our $VERSION = '1.9.15';
 our @ISA     = qw(Lemonldap::NG::Common::Conf::Constants);
 our ( @EXPORT, %EXPORT_TAGS );
 
@@ -62,7 +62,10 @@ sub _dbh {
         $self->{_dbh}->{sqlite_unicode} = 1;
     }
     elsif ( $self->{dbiChain} =~ /^dbi:mysql/i ) {
-        $self->{_dbh}->{mysql_enable_utf8} = 1;
+        eval {
+            $self->{_dbh}->{mysql_enable_utf8} = 1;
+            $self->{_dbh}->do("set names 'utf8'");
+        };
     }
     elsif ( $self->{dbiChain} =~ /^dbi:pg/i ) {
         $self->{_dbh}->{pg_enable_utf8} = 1;
